<?php

function alignFile($srcFileName, $targetFileName, $fileSuffix) {
	$IMAGE_SUFFIX_DIMENSIONS_ARRAY = getIMAGE_SUFFIX_DIMENSIONS_ARRAY();
	if(!file_exists($targetFileName) || filemtime($srcFileName) > filemtime($targetFileName)) {
		if(isImageFile($srcFileName) && array_key_exists($fileSuffix, $IMAGE_SUFFIX_DIMENSIONS_ARRAY)) {
			resizeImageFromFileToFile($srcFileName, $targetFileName, $IMAGE_SUFFIX_DIMENSIONS_ARRAY[$fileSuffix][0], $IMAGE_SUFFIX_DIMENSIONS_ARRAY[$fileSuffix][1]);
		} else {
			copy($srcFileName, $targetFileName);
		}
	}
}

function alignDir($srcPath, $targetPath, $fileFilter, $fileSuffix) {
	if($fileSuffix == '' || preg_match(CHECK_WILDCARDS_REGEXP, $fileSuffix)) {
		throw new Exception('[contentUtil][alignDir]: fileSuffix must be literal');
	}
	
	$fileArray = getFilesList($srcPath, ALL_FILES_REGEXP, SCANDIR_SORT_ASCENDING);
	
	if(!empty($fileArray)) {
		if(!file_exists($targetPath)) {
			mkdir($targetPath);
		}
		
		foreach($fileArray as $file) {
			if(preg_match($fileFilter, $file)) {
				alignFile($srcPath.'/'.$file, $targetPath.'/'.addSuffixToFileName($file, $fileSuffix), $fileSuffix);
			}
		}
	}
	
	$fileArray = getFilesList($targetPath, ALL_FILES_REGEXP, SCANDIR_SORT_ASCENDING);
	
	foreach($fileArray as $file) {
		if(preg_match('/^.*'.$fileSuffix.'\.'.getFileExtension($file).'$/i', $file)) {
			if(!file_exists($srcPath.'/'.removeSuffixFromFileName($file, $fileSuffix))) {
				unlink($targetPath.'/'.$file);
			}
		}
	}
}

function allFilesFromFStoHTML($path, $classes, $addTitle, $reverseOrder) {
	$retArray = array();
	
	$fileArray = getFilesList($path, ALL_FILES_REGEXP, ($reverseOrder ? SCANDIR_SORT_DESCENDING : SCANDIR_SORT_ASCENDING));
	
	$i = 1;
	foreach($fileArray as $file) {
		
		if(isTextualFile($file)) {
			$retArray[TEXTUAL_ELEMENTS_KEY.$i] = getTextualFileContent($path.'/'.$file);
		} elseif(isImageFile($file)) {
			$retArray[IMAGE_ELEMENTS_KEY.$i] = addImgTag($path, $file, $classes[0], $addTitle[0]);
		} elseif(isPdfFile($file)) {
			$retArray[PDFLINK_ELEMENTS_KEY.$i] = addPdfLink($path, $file, $classes[1], $addTitle[1]);
		} elseif(isCompressedFile($file)) {
			$retArray[DOWNLOADLINK_ELEMENTS_KEY.$i] = addDownloadLink($path, $file, $classes[2], $addTitle[2]);
		}
		
		$i++;
	}
	
	return $retArray;
}

function textualFilesFromFStoHTML($path, $reverseOrder) {
	$retArray = array();
	
	$fileArray = getFilesList($path, TEXTUAL_FILES_REGEXP, ($reverseOrder ? SCANDIR_SORT_DESCENDING : SCANDIR_SORT_ASCENDING));
	
	foreach($fileArray as $file) {
		array_push($retArray, getTextualFileContent($path.'/'.$file));
	}
	
	return $retArray;
}

function imagesFilesFromFStoHTML($path, $classes, $addTitle, $reverseOrder) {
	$retArray = array();
	
	$fileArray = getFilesList($path, IMAGE_FILES_REGEXP, ($reverseOrder ? SCANDIR_SORT_DESCENDING : SCANDIR_SORT_ASCENDING));
	
	foreach($fileArray as $file) {
		array_push($retArray, addImgTag($path, $file, $classes, $addTitle));
	}
	
	return $retArray;
}

function pdfFilesFromFStoHTML($path, $classes, $addTitle, $reverseOrder) {
	$retArray = array();
	
	$fileArray = getFilesList($path, PDF_FILES_REGEXP, ($reverseOrder ? SCANDIR_SORT_DESCENDING : SCANDIR_SORT_ASCENDING));
	
	foreach($fileArray as $file) {
		array_push($retArray, addPdfLink($path, $file, $classes, $addTitle));
	}
	
	return $retArray;
}

function compressedFilesFromFStoHTML($path, $classes, $addTitle, $reverseOrder) {
	$retArray = array();
	
	$fileArray = getFilesList($path, COMPRESSED_FILES_REGEXP, ($reverseOrder ? SCANDIR_SORT_DESCENDING : SCANDIR_SORT_ASCENDING));
	
	foreach($fileArray as $file) {
		array_push($retArray, addDownloadLink($path, $file, $classes, $addTitle));
	}
	
	return $retArray;
}

function addImgTag($path, $file, $classes, $addTitle) {
	return '<img class="'.$classes.'" src="'.$path.'/'.$file.'" alt="'.getFileNameNoExt($file).'"'.($addTitle ? ' title="'.getFileNameNoExt($file).'"' : '').'>';
}

function addPdfLink($path, $file, $classes, $addTitle) {
	return '<a class="'.$classes.'" href="'.$path.'/'.$file.'" target="_blank">'.addImgTag(HYPERTEXT_PROTOCOL.'://'.DOMAIN_NAME.'/framework/img/icons', 'apri pdf.png', '', $addTitle).'</a>';
}

function addDownloadLink($path, $file, $classes, $addTitle) {
	return '<a class="'.$classes.'" href="'.$path.'/'.$file.'" download>'.addImgTag(HYPERTEXT_PROTOCOL.'://'.DOMAIN_NAME.'/framework/img/icons', 'download file.png', '', $addTitle).'</a>';
}

function nestChildrenInParent($parentElementTag, $childrenElements, $parentElementClasses, $parentElementAttributes) {
	$html = '<'.$parentElementTag.' class="'.$parentElementClasses.'" '.$parentElementAttributes.'>';
	
	foreach($childrenElements as $child) {
		$html .= $child;
	}
	
	$html .= '</'.$parentElementTag.'>';
	
	return $html;
}

?>